## TractaML <sub> - taking subjectivity out of ML </sub>

<br/>

This package aims at solving some of the most important problems that machine learning (ML) practitioners face on a daily basis, but still use sub-optimal methods to tackle them. Having this broad vision in mind, the first version of this package solves one such problem – Combined hyper-parameter tuning and feature selection. 

### Installation

To install the package using pip:

```
pip install tracta-ml
```

### Documentation

Please refer to [documentation.md](documentation.md) for more details on package functionality.

### Sample code

The [example.py](example.py) code presents a working example on the [Wisconsin Breast Cancer (Diagnostic) dataset](https://archive.ics.uci.edu/ml/datasets/Breast+Cancer+Wisconsin+(Diagnostic)).

### Authors
- Sanketh Nagarajan (sanketh.objml@gmail.com)


### License
This project is licensed under the 3-Clause BSD License - see the [LICENSE.md](LICENSE) file for details


### To cite
Please use the following format to cite this package:

N. Sanketh, "TractaML - taking subjectivity out of ML", (2018), GitHub, https://github.com/SankethNagarajan/tracta_ml

### Keywords

- Combined hyper-parameter tuning and feature selection
- Micro GA
- Optimizing machine learning models
- Automatic model tuning




